@@ -94,6 +94,9 @@
 #define CONFIG_REDECL_WARN	44
 #define CONFIG_DUPVAR_WARN	45
 #define CONFIG_HZ	46
+#define CONFIG_TILDE_SPACE	47
+#define CONFIG_FRACTION_SPACE	48
+#define CONFIG_COMPLEX_SPACE	49
 
 
 /*
@@ -123,7 +126,7 @@ struct config {
 	int outmode2;		/* current secondary output mode */
 	LEN outdigits;		/* current output digits for float or exp */
 	NUMBER *epsilon;	/* default error for real functions */
-	    long epsilonprec;	/* epsilon binary precision (tied to epsilon) */
+	long epsilonprec;	/* epsilon binary precision (tied to epsilon) */
 	FLAG traceflags;	/* tracing flags */
 	LEN maxprint;		/* number of elements to print */
 	LEN mul2;		/* size of number to use multiply algorithm 2 */
@@ -131,6 +134,9 @@ struct config {
 	LEN pow2;		/* size of modulus to use REDC for powers */
 	LEN redc2;		/* size of modulus to use REDC algorithm 2 */
 	BOOL tilde_ok;		/* OK to print a tilde on approximations */
+	BOOL tilde_space;	/* print space after tilde on approximations */
+	BOOL fraction_space;	/* TRUE => print spaces around / in fractions */
+	BOOL complex_space;	/* TRUE => print spaces around + or - in complex values */
 	BOOL tab_ok;		/* OK to print tab before numeric values */
 	LEN quomod;		/* quomod() default rounding mode */
 	LEN quo;		/* quotient // default rounding mode */
