@@ -41,6 +41,7 @@
 # include "calc/longbits.h"
 # include "calc/byteswap.h"
 # include "calc/have_stdlib.h"
+# include "calc/attribute.h"
 #else
 # include <calc/decl.h>
 # include <calc/alloc.h>
@@ -48,6 +49,7 @@
 # include <calc/longbits.h>
 # include <calc/byteswap.h>
 # include <calc/have_stdlib.h>
+# include <calc/attribute.h>
 #endif
 #ifdef HAVE_STDLIB_H
 # include <stdlib.h>
@@ -604,7 +606,7 @@ E_FUNC void zredcpower(REDC *rp, ZVALUE z1, ZVALUE z2, ZVALUE *res);
 #define MODE2_OFF	(MODE_MAX+1)
 
 /* XXX - perhaps we need the MODE_REAL_AUTO vs MODE_REAL as a config mode? */
-#if 0 	/* XXX - can we safely set MODE_INITIAL to MODE_REAL_AUTO ?? */
+#if 0	/* XXX - can we safely set MODE_INITIAL to MODE_REAL_AUTO ?? */
 #define MODE_INITIAL	MODE_REAL_AUTO
 #else
 #define MODE_INITIAL	MODE_REAL
@@ -625,13 +627,14 @@ E_FUNC char *math_getdivertedio(void);
 E_FUNC int math_setmode(int mode);
 E_FUNC int math_setmode2(int mode);
 E_FUNC LEN math_setdigits(LEN digits);
-E_FUNC void math_fmt(char *, ...) PRINTF_FORMAT(1, 2);
+E_FUNC void math_fmt(char *, ...) __attribute__((format(printf, 1, 2)));
 
 
 /*
  * The error routine.
  */
-E_FUNC void math_error(char *, ...) PRINTF_FORMAT(1, 2);
+E_FUNC void math_error(char *, ...) \
+	__attribute__((format(printf, 1, 2))) __attribute__((noreturn));
 
 
 /*
@@ -640,6 +643,7 @@ E_FUNC void math_error(char *, ...) PRINTF_FORMAT(1, 2);
 E_FUNC HALF *swap_b8_in_HALFs(HALF *dest, HALF *src, LEN len);
 E_FUNC ZVALUE *swap_b8_in_ZVALUE(ZVALUE *dest, ZVALUE *src, BOOL all);
 E_FUNC HALF *swap_b16_in_HALFs(HALF *dest, HALF *src, LEN len);
+E_FUNC HALF *swap_HALFs(HALF *dest, HALF *src, LEN len);
 E_FUNC ZVALUE *swap_b16_in_ZVALUE(ZVALUE *dest, ZVALUE *src, BOOL all);
 E_FUNC ZVALUE *swap_HALF_in_ZVALUE(ZVALUE *dest, ZVALUE *src, BOOL all);
 
